@@ -1,15 +1,16 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
+from trytond.i18n import gettext
 from trytond.model import fields
 from trytond.pyson import Eval
 from trytond.pool import PoolMeta
 from . import luhn
+from .exceptions import SIRETValidationError
 
 __all__ = ['Address']
-__metaclass__ = PoolMeta
 
 
-class Address:
+class Address(metaclass=PoolMeta):
     __name__ = 'party.address'
 
     siret_nic = fields.Char('SIRET NIC', select=True, states={
@@ -17,20 +18,16 @@ class Address:
             }, size=5, depends=['active'])
     siret = fields.Function(fields.Char('SIRET'), 'get_siret')
 
-    @classmethod
-    def __setup__(cls):
-        super(Address, cls).__setup__()
-        cls._constraints += [
-            ('check_siret', 'invalid_siret'),
-            ]
-        cls._error_messages.update({
-                'invalid_siret': 'Invalid SIRET number!',
-                })
-
     def get_siret(self, name):
         if self.party.siren and self.siret_nic:
             return self.party.siren + self.siret_nic
 
+    @classmethod
+    def validate(cls, addresses):
+        super(Address, cls).validate(addresses)
+        for address in addresses:
+            address.check_siret()
+
     def check_siret(self):
         '''
         Check validity of SIRET
@@ -38,5 +35,7 @@ class Address:
         if self.siret:
             if (len(self.siret) != 14
                     or not luhn.validate(self.siret)):
-                return False
-        return True
+                raise SIRETValidationError(
+                    gettext('party_siret.msg_invalid_siret',
+                        number=self.siret,
+                        address=self.rec_name))
