@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 
 def validate(value):
@@ -8,7 +8,7 @@ def validate(value):
     :param value: the value
     :return: a boolean
     """
-    if not isinstance(value, basestring):
+    if not isinstance(value, str):
         value = str(value)
     try:
         evens = sum(int(x) for x in value[-1::-2])
